<?php
session_start(); // Initialize Session data
ob_start(); // Turn on output buffering
?>
<?php include "ewcfg7.php" ?>
<?php include "ewmysql7.php" ?>
<?php include "phpfn7.php" ?>
<?php include "tbl_hotel_submenuinfo.php" ?>
<?php include "tbl_hotelinfo.php" ?>
<?php include "tbl_languageinfo.php" ?>
<?php include "tbl_admininfo.php" ?>
<?php include "userfn7.php" ?>
<?php
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Date in the past
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); // Always modified
header("Cache-Control: private, no-store, no-cache, must-revalidate"); // HTTP/1.1 
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache"); // HTTP/1.0
?>
<?php

// Create page object
$tbl_hotel_submenu_delete = new ctbl_hotel_submenu_delete();
$Page =& $tbl_hotel_submenu_delete;

// Page init
$tbl_hotel_submenu_delete->Page_Init();

// Page main
$tbl_hotel_submenu_delete->Page_Main();
?>
<?php include "header.php" ?>
<script type="text/javascript">
<!--

// Create page object
var tbl_hotel_submenu_delete = new ew_Page("tbl_hotel_submenu_delete");

// page properties
tbl_hotel_submenu_delete.PageID = "delete"; // page ID
tbl_hotel_submenu_delete.FormID = "ftbl_hotel_submenudelete"; // form ID
var EW_PAGE_ID = tbl_hotel_submenu_delete.PageID; // for backward compatibility

// extend page with Form_CustomValidate function
tbl_hotel_submenu_delete.Form_CustomValidate =  
 function(fobj) { // DO NOT CHANGE THIS LINE!

 	// Your custom validation code here, return false if invalid. 
 	return true;
 }
<?php if (EW_CLIENT_VALIDATE) { ?>
tbl_hotel_submenu_delete.ValidateRequired = true; // uses JavaScript validation
<?php } else { ?>
tbl_hotel_submenu_delete.ValidateRequired = false; // no JavaScript validation
<?php } ?>

//-->
</script>
<script language="JavaScript" type="text/javascript">
<!--

// Write your client script here, no need to add script tags.
// To include another .js script, use:
// ew_ClientScriptInclude("my_javascript.js"); 
//-->

</script>
<?php

// Load records for display
if ($rs = $tbl_hotel_submenu_delete->LoadRecordset())
	$tbl_hotel_submenu_deletelTotalRecs = $rs->RecordCount(); // Get record count
if ($tbl_hotel_submenu_deletelTotalRecs <= 0) { // No record found, exit
	if ($rs)
		$rs->Close();
	$tbl_hotel_submenu_delete->Page_Terminate("tbl_hotel_submenulist.php"); // Return to list
}
?>
<p><span class="phpmaker"><?php echo $Language->Phrase("Delete") ?>&nbsp;<?php echo $Language->Phrase("TblTypeTABLE") ?><?php echo $tbl_hotel_submenu->TableCaption() ?><br><br>
<a href="<?php echo $tbl_hotel_submenu->getReturnUrl() ?>"><?php echo $Language->Phrase("GoBack") ?></a></span></p>
<?php
if (EW_DEBUG_ENABLED)
	echo ew_DebugMsg();
$tbl_hotel_submenu_delete->ShowMessage();
?>
<form action="<?php echo ew_CurrentPage() ?>" method="post">
<p>
<input type="hidden" name="t" id="t" value="tbl_hotel_submenu">
<input type="hidden" name="a_delete" id="a_delete" value="D">
<?php foreach ($tbl_hotel_submenu_delete->arRecKeys as $key) { ?>
<input type="hidden" name="key_m[]" id="key_m[]" value="<?php echo ew_HtmlEncode($key) ?>">
<?php } ?>
<table class="ewGrid"><tr><td class="ewGridContent">
<div class="ewGridMiddlePanel">
<table cellspacing="0" class="ewTable ewTableSeparate">
<?php echo $tbl_hotel_submenu->TableCustomInnerHtml ?>
	<thead>
	<tr class="ewTableHeader">
		<td valign="top"><?php echo $tbl_hotel_submenu->hotel_id->FldCaption() ?></td>
		<td valign="top"><?php echo $tbl_hotel_submenu->language_id->FldCaption() ?></td>
		<td valign="top"><?php echo $tbl_hotel_submenu->title->FldCaption() ?></td>
	</tr>
	</thead>
	<tbody>
<?php
$tbl_hotel_submenu_delete->lRecCnt = 0;
$i = 0;
while (!$rs->EOF) {
	$tbl_hotel_submenu_delete->lRecCnt++;

	// Set row properties
	$tbl_hotel_submenu->CssClass = "";
	$tbl_hotel_submenu->CssStyle = "";
	$tbl_hotel_submenu->RowAttrs = array();
	$tbl_hotel_submenu->RowType = EW_ROWTYPE_VIEW; // View

	// Get the field contents
	$tbl_hotel_submenu_delete->LoadRowValues($rs);

	// Render row
	$tbl_hotel_submenu_delete->RenderRow();
?>
	<tr<?php echo $tbl_hotel_submenu->RowAttributes() ?>>
		<td<?php echo $tbl_hotel_submenu->hotel_id->CellAttributes() ?>>
<div<?php echo $tbl_hotel_submenu->hotel_id->ViewAttributes() ?>><?php echo $tbl_hotel_submenu->hotel_id->ListViewValue() ?></div></td>
		<td<?php echo $tbl_hotel_submenu->language_id->CellAttributes() ?>>
<div<?php echo $tbl_hotel_submenu->language_id->ViewAttributes() ?>><?php echo $tbl_hotel_submenu->language_id->ListViewValue() ?></div></td>
		<td<?php echo $tbl_hotel_submenu->title->CellAttributes() ?>>
<div<?php echo $tbl_hotel_submenu->title->ViewAttributes() ?>><?php echo $tbl_hotel_submenu->title->ListViewValue() ?></div></td>
	</tr>
<?php
	$rs->MoveNext();
}
$rs->Close();
?>
</tbody>
</table>
</div>
</td></tr></table>
<p>
<input type="submit" name="Action" id="Action" value="<?php echo ew_BtnCaption($Language->Phrase("DeleteBtn")) ?>">
</form>
<script language="JavaScript" type="text/javascript">
<!--

// Write your table-specific startup script here
// document.write("page loaded");
//-->

</script>
<?php include "footer.php" ?>
<?php
$tbl_hotel_submenu_delete->Page_Terminate();
?>
<?php

//
// Page class
//
class ctbl_hotel_submenu_delete {

	// Page ID
	var $PageID = 'delete';

	// Table name
	var $TableName = 'tbl_hotel_submenu';

	// Page object name
	var $PageObjName = 'tbl_hotel_submenu_delete';

	// Page name
	function PageName() {
		return ew_CurrentPage();
	}

	// Page URL
	function PageUrl() {
		$PageUrl = ew_CurrentPage() . "?";
		global $tbl_hotel_submenu;
		if ($tbl_hotel_submenu->UseTokenInUrl) $PageUrl .= "t=" . $tbl_hotel_submenu->TableVar . "&"; // Add page token
		return $PageUrl;
	}

	// Page URLs
	var $AddUrl;
	var $EditUrl;
	var $CopyUrl;
	var $DeleteUrl;
	var $ViewUrl;
	var $ListUrl;

	// Export URLs
	var $ExportPrintUrl;
	var $ExportHtmlUrl;
	var $ExportExcelUrl;
	var $ExportWordUrl;
	var $ExportXmlUrl;
	var $ExportCsvUrl;

	// Update URLs
	var $InlineAddUrl;
	var $InlineCopyUrl;
	var $InlineEditUrl;
	var $GridAddUrl;
	var $GridEditUrl;
	var $MultiDeleteUrl;
	var $MultiUpdateUrl;

	// Message
	function getMessage() {
		return @$_SESSION[EW_SESSION_MESSAGE];
	}

	function setMessage($v) {
		if (@$_SESSION[EW_SESSION_MESSAGE] <> "") { // Append
			$_SESSION[EW_SESSION_MESSAGE] .= "<br>" . $v;
		} else {
			$_SESSION[EW_SESSION_MESSAGE] = $v;
		}
	}

	// Show message
	function ShowMessage() {
		$sMessage = $this->getMessage();
		$this->Message_Showing($sMessage);
		if ($sMessage <> "") { // Message in Session, display
			echo "<p><span class=\"ewMessage\">" . $sMessage . "</span></p>";
			$_SESSION[EW_SESSION_MESSAGE] = ""; // Clear message in Session
		}
	}

	// Validate page request
	function IsPageRequest() {
		global $objForm, $tbl_hotel_submenu;
		if ($tbl_hotel_submenu->UseTokenInUrl) {
			if ($objForm)
				return ($tbl_hotel_submenu->TableVar == $objForm->GetValue("t"));
			if (@$_GET["t"] <> "")
				return ($tbl_hotel_submenu->TableVar == $_GET["t"]);
		} else {
			return TRUE;
		}
	}

	//
	// Page class constructor
	//
	function ctbl_hotel_submenu_delete() {
		global $conn, $Language;

		// Language object
		$Language = new cLanguage();

		// Table object (tbl_hotel_submenu)
		$GLOBALS["tbl_hotel_submenu"] = new ctbl_hotel_submenu();

		// Table object (tbl_hotel)
		$GLOBALS['tbl_hotel'] = new ctbl_hotel();

		// Table object (tbl_language)
		$GLOBALS['tbl_language'] = new ctbl_language();

		// Table object (tbl_admin)
		$GLOBALS['tbl_admin'] = new ctbl_admin();

		// Page ID
		if (!defined("EW_PAGE_ID"))
			define("EW_PAGE_ID", 'delete', TRUE);

		// Table name (for backward compatibility)
		if (!defined("EW_TABLE_NAME"))
			define("EW_TABLE_NAME", 'tbl_hotel_submenu', TRUE);

		// Start timer
		$GLOBALS["gsTimer"] = new cTimer();

		// Open connection
		$conn = ew_Connect();
	}

	// 
	//  Page_Init
	//
	function Page_Init() {
		global $gsExport, $gsExportFile, $UserProfile, $Language, $Security, $objForm;
		global $tbl_hotel_submenu;

		// Security
		$Security = new cAdvancedSecurity();
		if (!$Security->IsLoggedIn()) $Security->AutoLogin();
		if (!$Security->IsLoggedIn()) {
			$Security->SaveLastUrl();
			$this->Page_Terminate("login.php");
		}

		// Global Page Loading event (in userfn*.php)
		Page_Loading();

		// Page Load event
		$this->Page_Load();
	}

	//
	// Page_Terminate
	//
	function Page_Terminate($url = "") {
		global $conn;

		// Page Unload event
		$this->Page_Unload();

		// Global Page Unloaded event (in userfn*.php)
		Page_Unloaded();

		 // Close connection
		$conn->Close();

		// Go to URL if specified
		$this->Page_Redirecting($url);
		if ($url <> "") {
			if (!EW_DEBUG_ENABLED && ob_get_length())
				ob_end_clean();
			header("Location: " . $url);
		}
		exit();
	}
	var $lTotalRecs = 0;
	var $lRecCnt;
	var $arRecKeys = array();

	//
	// Page main
	//
	function Page_Main() {
		global $Language, $tbl_hotel_submenu;

		// Load key parameters
		$sKey = "";
		$bSingleDelete = TRUE; // Initialize as single delete
		$nKeySelected = 0; // Initialize selected key count
		$sFilter = "";
		if (@$_GET["submenu_id"] <> "") {
			$tbl_hotel_submenu->submenu_id->setQueryStringValue($_GET["submenu_id"]);
			if (!is_numeric($tbl_hotel_submenu->submenu_id->QueryStringValue))
				$this->Page_Terminate("tbl_hotel_submenulist.php"); // Prevent SQL injection, exit
			$sKey .= $tbl_hotel_submenu->submenu_id->QueryStringValue;
		} else {
			$bSingleDelete = FALSE;
		}
		if ($bSingleDelete) {
			$nKeySelected = 1; // Set up key selected count
			$this->arRecKeys[0] = $sKey;
		} else {
			if (isset($_POST["key_m"])) { // Key in form
				$nKeySelected = count($_POST["key_m"]); // Set up key selected count
				$this->arRecKeys = ew_StripSlashes($_POST["key_m"]);
			}
		}
		if ($nKeySelected <= 0)
			$this->Page_Terminate("tbl_hotel_submenulist.php"); // No key specified, return to list

		// Build filter
		foreach ($this->arRecKeys as $sKey) {
			$sFilter .= "(";

			// Set up key field
			$sKeyFld = $sKey;
			if (!is_numeric($sKeyFld))
				$this->Page_Terminate("tbl_hotel_submenulist.php"); // Prevent SQL injection, return to list
			$sFilter .= "`submenu_id`=" . ew_AdjustSql($sKeyFld) . " AND ";
			if (substr($sFilter, -5) == " AND ") $sFilter = substr($sFilter, 0, strlen($sFilter)-5) . ") OR ";
		}
		if (substr($sFilter, -4) == " OR ") $sFilter = substr($sFilter, 0, strlen($sFilter)-4);

		// Set up filter (SQL WHHERE clause) and get return SQL
		// SQL constructor in tbl_hotel_submenu class, tbl_hotel_submenuinfo.php

		$tbl_hotel_submenu->CurrentFilter = $sFilter;

		// Get action
		if (@$_POST["a_delete"] <> "") {
			$tbl_hotel_submenu->CurrentAction = $_POST["a_delete"];
		} else {
			$tbl_hotel_submenu->CurrentAction = "D"; // Delete record directly
		}
		switch ($tbl_hotel_submenu->CurrentAction) {
			case "D": // Delete
				$tbl_hotel_submenu->SendEmail = TRUE; // Send email on delete success
				if ($this->DeleteRows()) { // delete rows
					$this->setMessage($Language->Phrase("DeleteSuccess")); // Set up success message
					$this->Page_Terminate($tbl_hotel_submenu->getReturnUrl()); // Return to caller
				}
		}
	}

	//
	// Delete records based on current filter
	//
	function DeleteRows() {
		global $conn, $Language, $Security, $tbl_hotel_submenu;
		$DeleteRows = TRUE;
		$sWrkFilter = $tbl_hotel_submenu->CurrentFilter;

		// Set up filter (SQL WHERE clause) and get return SQL
		// SQL constructor in tbl_hotel_submenu class, tbl_hotel_submenuinfo.php

		$tbl_hotel_submenu->CurrentFilter = $sWrkFilter;
		$sSql = $tbl_hotel_submenu->SQL();
		$conn->raiseErrorFn = 'ew_ErrorFn';
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';
		if ($rs === FALSE) {
			return FALSE;
		} elseif ($rs->EOF) {
			$this->setMessage($Language->Phrase("NoRecord")); // No record found
			$rs->Close();
			return FALSE;
		}
		$conn->BeginTrans();

		// Clone old rows
		$rsold = ($rs) ? $rs->GetRows() : array();
		if ($rs)
			$rs->Close();

		// Call row deleting event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$DeleteRows = $tbl_hotel_submenu->Row_Deleting($row);
				if (!$DeleteRows) break;
			}
		}
		if ($DeleteRows) {
			$sKey = "";
			foreach ($rsold as $row) {
				$sThisKey = "";
				if ($sThisKey <> "") $sThisKey .= EW_COMPOSITE_KEY_SEPARATOR;
				$sThisKey .= $row['submenu_id'];
				$conn->raiseErrorFn = 'ew_ErrorFn';
				$DeleteRows = $conn->Execute($tbl_hotel_submenu->DeleteSQL($row)); // Delete
				$conn->raiseErrorFn = '';
				if ($DeleteRows === FALSE)
					break;
				if ($sKey <> "") $sKey .= ", ";
				$sKey .= $sThisKey;
			}
		} else {

			// Set up error message
			if ($tbl_hotel_submenu->CancelMessage <> "") {
				$this->setMessage($tbl_hotel_submenu->CancelMessage);
				$tbl_hotel_submenu->CancelMessage = "";
			} else {
				$this->setMessage($Language->Phrase("DeleteCancelled"));
			}
		}
		if ($DeleteRows) {
			$conn->CommitTrans(); // Commit the changes
		} else {
			$conn->RollbackTrans(); // Rollback changes
		}

		// Call Row Deleted event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$tbl_hotel_submenu->Row_Deleted($row);
			}	
		}
		return $DeleteRows;
	}

	// Load recordset
	function LoadRecordset($offset = -1, $rowcnt = -1) {
		global $conn, $tbl_hotel_submenu;

		// Call Recordset Selecting event
		$tbl_hotel_submenu->Recordset_Selecting($tbl_hotel_submenu->CurrentFilter);

		// Load List page SQL
		$sSql = $tbl_hotel_submenu->SelectSQL();
		if ($offset > -1 && $rowcnt > -1)
			$sSql .= " LIMIT $offset, $rowcnt";

		// Load recordset
		$rs = ew_LoadRecordset($sSql);

		// Call Recordset Selected event
		$tbl_hotel_submenu->Recordset_Selected($rs);
		return $rs;
	}

	// Load row based on key values
	function LoadRow() {
		global $conn, $Security, $tbl_hotel_submenu;
		$sFilter = $tbl_hotel_submenu->KeyFilter();

		// Call Row Selecting event
		$tbl_hotel_submenu->Row_Selecting($sFilter);

		// Load SQL based on filter
		$tbl_hotel_submenu->CurrentFilter = $sFilter;
		$sSql = $tbl_hotel_submenu->SQL();
		$res = FALSE;
		$rs = ew_LoadRecordset($sSql);
		if ($rs && !$rs->EOF) {
			$res = TRUE;
			$this->LoadRowValues($rs); // Load row values

			// Call Row Selected event
			$tbl_hotel_submenu->Row_Selected($rs);
			$rs->Close();
		}
		return $res;
	}

	// Load row values from recordset
	function LoadRowValues(&$rs) {
		global $conn, $tbl_hotel_submenu;
		$tbl_hotel_submenu->submenu_id->setDbValue($rs->fields('submenu_id'));
		$tbl_hotel_submenu->hotel_id->setDbValue($rs->fields('hotel_id'));
		$tbl_hotel_submenu->language_id->setDbValue($rs->fields('language_id'));
		$tbl_hotel_submenu->title->setDbValue($rs->fields('title'));
		$tbl_hotel_submenu->description->setDbValue($rs->fields('description'));
	}

	// Render row values based on field settings
	function RenderRow() {
		global $conn, $Security, $Language, $tbl_hotel_submenu;

		// Initialize URLs
		// Call Row_Rendering event

		$tbl_hotel_submenu->Row_Rendering();

		// Common render codes for all row types
		// hotel_id

		$tbl_hotel_submenu->hotel_id->CellCssStyle = ""; $tbl_hotel_submenu->hotel_id->CellCssClass = "";
		$tbl_hotel_submenu->hotel_id->CellAttrs = array(); $tbl_hotel_submenu->hotel_id->ViewAttrs = array(); $tbl_hotel_submenu->hotel_id->EditAttrs = array();

		// language_id
		$tbl_hotel_submenu->language_id->CellCssStyle = ""; $tbl_hotel_submenu->language_id->CellCssClass = "";
		$tbl_hotel_submenu->language_id->CellAttrs = array(); $tbl_hotel_submenu->language_id->ViewAttrs = array(); $tbl_hotel_submenu->language_id->EditAttrs = array();

		// title
		$tbl_hotel_submenu->title->CellCssStyle = ""; $tbl_hotel_submenu->title->CellCssClass = "";
		$tbl_hotel_submenu->title->CellAttrs = array(); $tbl_hotel_submenu->title->ViewAttrs = array(); $tbl_hotel_submenu->title->EditAttrs = array();
		if ($tbl_hotel_submenu->RowType == EW_ROWTYPE_VIEW) { // View row

			// submenu_id
			$tbl_hotel_submenu->submenu_id->ViewValue = $tbl_hotel_submenu->submenu_id->CurrentValue;
			$tbl_hotel_submenu->submenu_id->CssStyle = "";
			$tbl_hotel_submenu->submenu_id->CssClass = "";
			$tbl_hotel_submenu->submenu_id->ViewCustomAttributes = "";

			// hotel_id
			if (strval($tbl_hotel_submenu->hotel_id->CurrentValue) <> "") {
				$sFilterWrk = "`hotel_or_id` = " . ew_AdjustSql($tbl_hotel_submenu->hotel_id->CurrentValue) . "";
			$sSqlWrk = "SELECT `hotel_name` FROM `tbl_hotel`";
			$sWhereWrk = "";
			if ($sFilterWrk <> "") {
				if ($sWhereWrk <> "") $sWhereWrk .= " AND ";
				$sWhereWrk .= "(" . $sFilterWrk . ")";
			}
			if ($sWhereWrk <> "") $sSqlWrk .= " WHERE " . $sWhereWrk;
				$rswrk = $conn->Execute($sSqlWrk);
				if ($rswrk && !$rswrk->EOF) { // Lookup values found
					$tbl_hotel_submenu->hotel_id->ViewValue = $rswrk->fields('hotel_name');
					$rswrk->Close();
				} else {
					$tbl_hotel_submenu->hotel_id->ViewValue = $tbl_hotel_submenu->hotel_id->CurrentValue;
				}
			} else {
				$tbl_hotel_submenu->hotel_id->ViewValue = NULL;
			}
			$tbl_hotel_submenu->hotel_id->CssStyle = "";
			$tbl_hotel_submenu->hotel_id->CssClass = "";
			$tbl_hotel_submenu->hotel_id->ViewCustomAttributes = "";

			// language_id
			if (strval($tbl_hotel_submenu->language_id->CurrentValue) <> "") {
				$sFilterWrk = "`language_id` = " . ew_AdjustSql($tbl_hotel_submenu->language_id->CurrentValue) . "";
			$sSqlWrk = "SELECT `language` FROM `tbl_language`";
			$sWhereWrk = "";
			if ($sFilterWrk <> "") {
				if ($sWhereWrk <> "") $sWhereWrk .= " AND ";
				$sWhereWrk .= "(" . $sFilterWrk . ")";
			}
			if ($sWhereWrk <> "") $sSqlWrk .= " WHERE " . $sWhereWrk;
				$rswrk = $conn->Execute($sSqlWrk);
				if ($rswrk && !$rswrk->EOF) { // Lookup values found
					$tbl_hotel_submenu->language_id->ViewValue = $rswrk->fields('language');
					$rswrk->Close();
				} else {
					$tbl_hotel_submenu->language_id->ViewValue = $tbl_hotel_submenu->language_id->CurrentValue;
				}
			} else {
				$tbl_hotel_submenu->language_id->ViewValue = NULL;
			}
			$tbl_hotel_submenu->language_id->CssStyle = "";
			$tbl_hotel_submenu->language_id->CssClass = "";
			$tbl_hotel_submenu->language_id->ViewCustomAttributes = "";

			// title
			$tbl_hotel_submenu->title->ViewValue = $tbl_hotel_submenu->title->CurrentValue;
			$tbl_hotel_submenu->title->CssStyle = "";
			$tbl_hotel_submenu->title->CssClass = "";
			$tbl_hotel_submenu->title->ViewCustomAttributes = "";

			// hotel_id
			$tbl_hotel_submenu->hotel_id->HrefValue = "";
			$tbl_hotel_submenu->hotel_id->TooltipValue = "";

			// language_id
			$tbl_hotel_submenu->language_id->HrefValue = "";
			$tbl_hotel_submenu->language_id->TooltipValue = "";

			// title
			$tbl_hotel_submenu->title->HrefValue = "";
			$tbl_hotel_submenu->title->TooltipValue = "";
		}

		// Call Row Rendered event
		if ($tbl_hotel_submenu->RowType <> EW_ROWTYPE_AGGREGATEINIT)
			$tbl_hotel_submenu->Row_Rendered();
	}

	// Page Load event
	function Page_Load() {

		//echo "Page Load";
	}

	// Page Unload event
	function Page_Unload() {

		//echo "Page Unload";
	}

	// Page Redirecting event
	function Page_Redirecting(&$url) {

		// Example:
		//$url = "your URL";

	}

	// Message Showing event
	function Message_Showing(&$msg) {

		// Example:
		//$msg = "your new message";

	}
}
?>
